{
  description = "docman is a document management tool";

  inputs = {
    nixpkgs.url = "nixpkgs/nixos-23.05";
  };

  outputs = { self, nixpkgs, ... }:
    let
      # Extract the version from version.json
      versionData = builtins.fromJSON (builtins.readFile ./version.json);
      version = versionData.version;

      # Convert the last modified date to ISO format
      lastModifiedDate = self.lastModifiedDate or self.lastModified or "19700101";
      isoDate = builtins.concatStringsSep "" [
        (builtins.substring 0 4 lastModifiedDate) 
        (builtins.substring 4 2 lastModifiedDate)
        (builtins.substring 6 2 lastModifiedDate)
      ];

      supportedSystems = [ "x86_64-linux" "x86_64-darwin" "aarch64-linux" "aarch64-darwin" ];

      forAllSystems = nixpkgs.lib.genAttrs supportedSystems;

      nixpkgsFor = forAllSystems (system: import nixpkgs { inherit system; });
      pkgs = import nixpkgs { system = "x86_64-linux"; };

    in
    {
      packages = forAllSystems (system:
        let
          pkgs = nixpkgsFor.${system};
        in
        {
          docman = pkgs.buildGoModule {

            name = "docman";
            version = version;

            src = ././source;

            vendorSha256 = "sha256-81IBG8H1jsYKD+tmFeCpAWFdz6cuQDt9r+FV56xboBU=";

            ldflags = [
              "-X 'gitlab.schukai.com/oss/utilities/documentation-manager/release.version=${version}' -X 'gitlab.schukai.com/oss/utilities/documentation-manager/release.build=${isoDate}'"
            ];

            meta = with nixpkgs.legacyPackages.${system}.lib; {
              description = "docman is a document management tool";
              homepage = "https://gitlab.schukai.com/oss/utilities/documentation-manager";
              license = licenses.mit;
              maintainers = with maintainers; [ "schukai GmbH" ];
            };
          };
        });

      devShells = forAllSystems (system:
        let
          pkgs = nixpkgsFor.${system};
        in
        {
          default = pkgs.mkShell {
            buildInputs = with pkgs; [ go gopls gotools go-tools ];
          };
        });

      defaultPackage = forAllSystems (system: self.packages.${system}.docman);
    };
}
