package command

import (
	"fmt"
	"gitlab.schukai.com/oss/utilities/documentation-manager/config"
	error2 "gitlab.schukai.com/oss/utilities/documentation-manager/error"

	"gitlab.schukai.com/oss/libraries/go/application/configuration"
	"gitlab.schukai.com/oss/libraries/go/application/xflags"
	"os"
)

var instance *xflags.Settings[CommandsStruct]

var helpInfo = "\nYou can use the --help flag to get more information about the command."

func Execute() {

	instance = xflags.New(os.Args[0], CommandsStruct{})
	if instance.HasErrors() {
		for _, msg := range instance.Errors() {
			error2.PrintError(msg.Error())
		}
		error2.Exit(1)
	}

	//proxy := configuration.Settings[config.AppConfig]{}
	//instance.SetProxy(&proxy)
	if instance.HasErrors() {
		for _, msg := range instance.Errors() {
			error2.PrintError(msg.Error())
		}
		error2.Exit(1)
	}

	instance.Parse(os.Args[1:])
	if instance.HelpRequested() {
		fmt.Println(instance.Help())
		return
	}

	if instance.HasErrors() {
		for _, msg := range instance.Errors() {
			error2.PrintError(msg.Error())
		}
		fmt.Println(helpInfo)
		error2.Exit(1)
	}

	config.SetUp(instance.GetValues().ConfigPath)

	if config.Instance.HasErrors() {
		for _, msg := range config.Instance.Errors() {
			error2.PrintError(msg.Error())
		}
		error2.Exit(1)
	}

	cfg := configuration.Settings[config.AppConfig]{}
	cfg.Copy(instance.GetMap())

	config.Instance.Merge(cfg.Config())

	//alvine.InitConfig()

	instance.Execute()
	if instance.HasErrors() {

		for _, msg := range instance.Errors() {
			error2.PrintError(msg.Error())
		}

		if instance.HasHint() {
			error2.PrintHint(instance.GetHint())
		}

		fmt.Println(helpInfo)
		error2.Exit(1)
	}

}
