// Copyright 2023 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package document

import (
	"crypto/md5"
	"fmt"
	"os"
	"path/filepath"
	"strings"
)

type SourceFile struct {
	//dateFormat string
	baseDir       string
	absSourcePath string
	relSourcePath string
	//targetPath string
	fileInfo os.FileInfo
	textMeta textMetaStruct
	hash     string
	level    int
}

func NewDefinition(root string, sourcePath string, info os.FileInfo, textMeta textMetaStruct) *SourceFile {

	r, _ := filepath.Rel(root, sourcePath)

	s := &SourceFile{
		relSourcePath: r,
		absSourcePath: sourcePath,
		fileInfo:      info,
		textMeta:      textMeta,
	}

	s.hash = fmt.Sprintf("%x", md5.Sum([]byte(r)))
	s.baseDir = filepath.Dir(sourcePath)

	d, _ := filepath.Split(s.relSourcePath)
	if d != "" {
		s.level = len(strings.Split(d, "/")) + 1
	} else {
		s.level = 1
	}

	return s
}

func (d *SourceFile) GetSourcePath() string {
	return d.absSourcePath
}
