package error

import (
	"github.com/gookit/color"
	"os"
)

func CheckError(err error) {
	if err != nil {
		PrintErrorAndExit(err.Error())
	}

}

func Exit(code int) {
	os.Exit(code)
}

var lastBlock string

func PrintHint(message string, a ...interface{}) {

	if lastBlock == "hint" {

		if a != nil {
			color.Info.Println("\t"+message, a)
			return
		}

		color.Info.Println("\t" + message)
		return
	}

	if a != nil {
		color.Info.Block(message, a...)
		return
	}

	color.Info.Block(message)
}

func PrintErrorAndExit(message string, a ...interface{}) {
	PrintError(message, a...)
	os.Exit(1)
}

func PrintError(message string, a ...interface{}) {

	if lastBlock == "error" {

		if a != nil {
			color.Error.Println("\t"+message, a)
			return
		}

		color.Error.Println("\t" + message)
		return
	}

	lastBlock = "error"

	if a != nil {
		color.Error.Block("\t"+message, a...)
		return
	}

	color.Error.Block("\t" + message)

}

func PrintWarning(message string, a ...interface{}) {

	if lastBlock == "warning" {

		if a != nil {
			color.Warn.Println("\t"+message, a)
			return
		}

		color.Warn.Println("\t" + message)
		return
	}

	lastBlock = "warning"

	if a != nil {
		color.Warn.Block(message, a...)
		return
	}

	color.Warn.Block(message)
}

func CheckErrors(err []error) {
	if len(err) == 0 {
		return
	}

	for _, e := range err {
		PrintError(e.Error())
	}

	os.Exit(1)

}
