// Copyright 2023 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package utils

import (
	"crypto/md5"
	"fmt"
	"gitlab.schukai.com/oss/utilities/documentation-manager/environment"
	"gitlab.schukai.com/oss/utilities/documentation-manager/translations"
	"regexp"
	"strconv"
	"strings"
)

func Substring(input string, start int, length int) string {
	runes := []rune(input)

	if start >= len(runes) {
		return ""
	}

	if start+length > len(runes) {
		length = len(runes) - start
	}

	return string(runes[start : start+length])
}

func TrimLines(s string) string {

	flag := false
	l := strings.Split(s, "\n")
	r := []string{}
	for _, v := range l {
		m := strings.TrimSpace(v)
		if m == "" {
			flag = true
			continue
		}

		if m != "" && flag {
			m += "\n"
		}

		flag = false
		r = append(r, m)
	}
	rs := strings.Join(r, "\n")

	return rs
}

func TrimQuotes(s string) string {
	if len(s) >= 2 {
		if s[0] == '"' && s[len(s)-1] == '"' {
			return s[1 : len(s)-1]
		}
	}
	return s
}

func InsertCodeBlocks(s string, m map[string]string) string {

	for k, v := range m {
		s = strings.Replace(s, k, v, -1)
	}

	return s

}

func MaskCodeBlocks(s, file string, count int) (string, map[string]string) {

	const marker = "__X42_2342XXY_CCX_"
	s = strings.Replace(s, "\\`", marker, -1)

	regEx := regexp.MustCompile(`(?m)(?P<match>((?P<open>[\x60]{` + strconv.Itoa(count) + `})(?P<code>[^\x60]+))(?P<close>[\x60]{` + strconv.Itoa(count) + `}))`)
	matches := regEx.FindAllStringSubmatch(s, -1)

	m := map[string]string{}

	for _, match := range matches {
		result := make(map[string]string)
		for i, name := range regEx.SubexpNames() {
			if i != 0 && name != "" {
				result[name] = match[i]
			}
		}

		if result["open"] != result["close"] {
			environment.State.AddWarning(translations.T.Sprintf("Code block %s,  in file %s, is not closed", result["match"], file))
			continue
		}

		//i := strings.Index(s, result["match"])
		//if i != -1 {
		//	q2 := Substring(s, i-20, 40)
		//	fmt.Println(q2)
		//	q := Substring(s, i-1, 1)
		//	if q == "\"" {
		//		continue
		//	}
		//}

		k := fmt.Sprintf("%x", md5.Sum([]byte(result["code"])))
		m[k] = result["match"]

		s = strings.Replace(s, result["match"], k, -1)

	}

	s = strings.Replace(s, marker, "\\`", -1)

	return s, m

}
